@@ -1,3 +1,5 @@
+from time import sleep
+
 from manga_py.fs import get_temp_path, make_dirs, remove_file_query_params, basename, path_join, dirname
 from .multi_threads import MultiThreads
 from .request import Request
@@ -32,24 +34,38 @@ class Http(Request):
                 raise AttributeError('{} type not {}'.format(name, _type))
             setattr(self, name, value)
 
+    def __download(self, file_name, url, method):
+        now_try_count = 0
+        while now_try_count < 10:
+            with open(file_name, 'wb') as out_file:
+                now_try_count += 1
+                response = self.requests(url, method=method, timeout=60, allow_redirects=True)
+                if response.status_code >= 400:
+                    self.debug and print('ERROR! Code {}\nUrl: {}'.format(
+                        response.status_code,
+                        url,
+                    ))
+                    continue
+                out_file.write(response.content)
+                response.close()
+                out_file.close()
+                break
+
     def _safe_downloader(self, url, file_name, method='get') -> bool:
         try:
             make_dirs(dirname(file_name))
             url = self.normalize_uri(url)
-            with open(file_name, 'wb') as out_file:
-                response = self.requests(url, method=method, timeout=60)
-                out_file.write(response.content)
-                response.close()
-                out_file.close()
+            self.__download(file_name, url, method)
         except OSError as ex:
             self.debug and print(ex)
             return False
         return True
 
-    def _download_one_file_helper(self, url, dst, callback: callable = None):
+    def _download_one_file_helper(self, url, dst, callback: callable = None, success_callback: callable = None):
         r = 0
         while r < self.count_retries:
             if self._safe_downloader(url, dst):
+                success_callback and success_callback(dst)
                 return True
 
             r += 1
@@ -59,11 +75,14 @@ class Http(Request):
             callable(callback) and callback(text=mode)
         return False
 
-    def download_file(self, url: str, dst: str = None, callback: callable = None) -> bool:
+    def download_file(self, url: str,
+                      dst: str = None,
+                      callback: callable = None,
+                      success_callback: callable = None) -> bool:
         if not dst:
             name = basename(remove_file_query_params(url))
             dst = path_join(get_temp_path(), name)
-        return self._download_one_file_helper(url, dst, callback)
+        return self._download_one_file_helper(url, dst, callback, success_callback)
 
     def normalize_uri(self, uri, referer=None):
         if not referer:
