@@ -104,6 +104,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
     def loop_files(self):
         if isinstance(self._storage['files'], list) and len(self._storage['files']) > 0:
             self._archive = Archive()
+            self._archive.not_change_files_extension = self._params.get('not_change_files_extension', False)
             self._call_files_progress_callback()
 
             if self._params.get('no_multi_threads', False):
@@ -119,21 +120,22 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
             _url = self.http().normalize_uri(self.get_current_file())
         else:
             _url = url
-
-        url = self.before_file_save(url, idx)
-
+        _url = self.before_file_save(_url, idx)
         filename = remove_file_query_params(basename(_url))
         _path = self.remove_not_ascii(self._image_name(idx, filename))
         _path = get_temp_path(_path)
-
-        return _path, idx, url
+        return _path, idx, _url
 
     def save_file(self, idx=None, callback=None, url=None, in_arc_name=None):
         _path, idx, _url = self._save_file_params_helper(url, idx)
 
         if not is_file(_path):
-            self.http().download_file(_url, _path)
-            self._archive.add_file(_path, in_arc_name)
+            # issue 55
+            if in_arc_name is None:
+                self.http().download_file(_url, _path, success_callback=self._archive.lazy_add)
+            else:
+                self.http().download_file(_url, _path)
+                self._archive.add_file(_path, in_arc_name)
         callable(callback) and callback()
         self.after_file_save(_path, idx)
 
@@ -196,6 +198,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
             self._storage['current_file'] = idx
             self._call_files_progress_callback()
             self.save_file()
+        self.progress()
 
     def cf_protect(self, url):
         """
