@@ -1,9 +1,12 @@
 import re
 
 providers_list = {
-    'ac_qq_com': {
+    '3asq_info': [
+        r'3asq\.info/',
+    ],
+    'ac_qq_com': [
         r'ac\.qq\.com/Comic.+?/id/\d',
-    },
+    ],
     'adulto_seinagi_org': [
         r'adulto\.seinagi\.org/(series|read)/.',
         r'xanime-seduccion\.com/(series|read)/.',
@@ -22,6 +25,9 @@ providers_list = {
     'asmhentai_com': [
         r'asmhentai\.com/(g|gallery)/\d'
     ],
+    'atfbooru_ninja': [
+        r'atfbooru.ninja/posts.',
+    ],
     'authrone_com': [
         r'authrone\.com/manga/.',
     ],
@@ -87,7 +93,7 @@ providers_list = {
     'e_hentai_org': [
         r'e-hentai\.org/g/\d',
     ],
-    'eight_muses_com': [
+    '8muses_com': [
         r'8muses\.com/comics/album/.',
     ],
     'fanfox_net': [
@@ -187,6 +193,7 @@ providers_list = {
         r'mangadenizi\.com/.',
         r'mangadoor\.com/manga/.',
         r'mangaid\.co/manga/.',
+        r'mangaid\.net/manga/.',
         r'manga\.fascans\.com/manga/.',
         r'mangadesu\.net/manga/.',
         r'mangahis\.com/manga/.',
@@ -206,9 +213,16 @@ providers_list = {
     'lector_kirishimafansub_com': [
         r'lector\.kirishimafansub\.com/(lector/)?(series|read)/.',
     ],
+    'leitor_net': [
+        r'leitor\.net/manga/.',
+    ],
     'leomanga_com': [
         r'leomanga\.com/manga/.',
     ],
+    'lolibooru_moe': [
+        r'lolibooru\.moe/post.',
+        r'yande\.re/post.',
+    ],
     'lolivault_net': [
         r'lolivault.net/online/(series|read)',
     ],
@@ -604,6 +618,10 @@ providers_list = {
     'truyen_vnsharing_site': [
         r'truyen\.vnsharing\.site/index/read/.',
     ],
+    'truyenchon_com': [
+        r'truyenchon\.com/truyen/.',
+        r'nettruyen\.com/truyen-tranh/.',
+    ],
     'truyentranhtuan_com': [
         r'truyentranhtuan.com/.',
     ],
@@ -613,10 +631,12 @@ providers_list = {
     ],
     'tumangaonline_com': [
         r'tumangaonline\.com/.',
+        r'tumangaonline\.me/.',
     ],
     'unionmangas_net': [
         r'unionmangas\.cc/(leitor|manga)/.',
         r'unionmangas\.net/(leitor|manga)/.',
+        r'unionmangas\.site/(leitor|manga)/.',
     ],
     # 'viz_com': [r'viz\.com/shonenjump/chapters/.',],
     'web_ace_jp': [
