@@ -4,13 +4,20 @@ from .helpers.std import Std
 
 class ReadmangaMe(Provider, Std):
 
+    def __current_ch(self):
+        _re = '/.+/(?:vol)?([^/]+/[^/]+)(?:/|\?ma?t)?'
+        name = self.re.search(_re, self.chapter).group(1)
+        if ~name.find('?'):
+            name = name[:name.find('?')]
+        return name
+
     def get_archive_name(self):
-        name = self.re.search('/.+/([^/]+/[^/]+)/?', self.chapter)
-        return self.normal_arc_name(name.group(1).split('/'))
+        name = self.__current_ch()
+        return self.normal_arc_name(name.split('/'))
 
     def get_chapter_index(self):
-        name = self.re.search('/.+/(?:vol)?([^/]+/[^/]+)/?', self.chapter)
-        return name.group(1).replace('/', '-')
+        name = self.__current_ch()
+        return name.replace('/', '-')
 
     def get_main_content(self):
         return self._get_content('{}/{}?mature=1&mtr=1')
